Class: Namecheap::Users
Constant Summary
Constants inherited from Api
Api::ENDPOINT, Api::ENVIRONMENT, Api::PRODUCTION, Api::SANDBOX
Instance Method Summary collapse
-
#change_password(options = {}) ⇒ Object
Changes the password for a user.
-
#create(options = {}) ⇒ Object
Creates a new user account at NameCheap.
-
#create_add_funds_request(options = {}) ⇒ Object
Allows you to add funds to a user account.
-
#get_add_funds_status(id, options = {}) ⇒ Object
Gets the status of add funds request.
-
#get_balances(options = {}) ⇒ Object
Gets information about fund in the user's account.
-
#get_pricing(options = {}) ⇒ Object
Returns pricing information for a requested product type.
-
#login(options = {}) ⇒ Object
Validates the username and password of user accounts you have created.
-
#reset_password(options = {}) ⇒ Object
Sends a reset password link to user.
-
#update(options = {}) ⇒ Object
Updates user account information for the particular user.
Methods inherited from Api
#delete, #get, #init_args, #post, #put, #request
Instance Method Details
#change_password(options = {}) ⇒ Object
Changes the password for a user.
23 24 25 |
# File 'lib/namecheap/users.rb', line 23 def change_password( = {}) get "users.changePassword", end |
#create(options = {}) ⇒ Object
Creates a new user account at NameCheap.
5 6 7 |
# File 'lib/namecheap/users.rb', line 5 def create( = {}) get "users.create", end |
#create_add_funds_request(options = {}) ⇒ Object
Allows you to add funds to a user account.
35 36 37 |
# File 'lib/namecheap/users.rb', line 35 def create_add_funds_request( = {}) get "users.createaddfundsrequest", end |
#get_add_funds_status(id, options = {}) ⇒ Object
Gets the status of add funds request.
41 42 43 44 |
# File 'lib/namecheap/users.rb', line 41 def get_add_funds_status(id, = {}) = {TokenId: id}.merge() get "users.getAddFundsStatus", end |
#get_balances(options = {}) ⇒ Object
Gets information about fund in the user's account.
17 18 19 |
# File 'lib/namecheap/users.rb', line 17 def get_balances( = {}) get "users.getBalances", end |
#get_pricing(options = {}) ⇒ Object
Returns pricing information for a requested product type.
11 12 13 |
# File 'lib/namecheap/users.rb', line 11 def get_pricing( = {}) get "users.getPricing", end |
#login(options = {}) ⇒ Object
Validates the username and password of user accounts you have created.
48 49 50 |
# File 'lib/namecheap/users.rb', line 48 def login( = {}) get "users.login", end |
#reset_password(options = {}) ⇒ Object
Sends a reset password link to user.
54 55 56 |
# File 'lib/namecheap/users.rb', line 54 def reset_password( = {}) get "users.resetPassword", end |
#update(options = {}) ⇒ Object
Updates user account information for the particular user.
29 30 31 |
# File 'lib/namecheap/users.rb', line 29 def update( = {}) get "users.update", end |